event_from_error

Function event_from_error 

pub fn event_from_error(err: &Error) -> Event<'static>
👎Deprecated:

The failure integration is deprecated and will be removed in the future.

Helper function to create an event from a failure::Error.